summaryrefslogtreecommitdiffstats
path: root/kalarm/alarmcalendar.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kalarm/alarmcalendar.cpp
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/alarmcalendar.cpp')
-rw-r--r--kalarm/alarmcalendar.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kalarm/alarmcalendar.cpp b/kalarm/alarmcalendar.cpp
index 7bdd767a..85bc1739 100644
--- a/kalarm/alarmcalendar.cpp
+++ b/kalarm/alarmcalendar.cpp
@@ -439,14 +439,14 @@ void AlarmCalendar::close()
/******************************************************************************
* Import alarms from an external calendar and merge them into KAlarm's calendar.
* The alarms are given new unique event IDs.
* Parameters: tqparent = tqparent widget for error message boxes
* Reply = true if all alarms in the calendar were successfully imported
* = false if any alarms failed to be imported.
*/
-bool AlarmCalendar::importAlarms(TQWidget* tqparent)
+bool AlarmCalendar::importAlarms(TQWidget* parent)
{
KURL url = KFileDialog::getOpenURL(TQString::tqfromLatin1(":importalarms"),
- TQString::tqfromLatin1("*.vcs *.ics|%1").tqarg(i18n("Calendar Files")), tqparent);
+ TQString::tqfromLatin1("*.vcs *.ics|%1").tqarg(i18n("Calendar Files")), parent);
if (url.isEmpty())
{
kdError(5950) << "AlarmCalendar::importAlarms(): Empty URL" << endl;
@@ -468,7 +468,7 @@ bool AlarmCalendar::importAlarms(TQWidget* tqparent)
if (!KStandardDirs::exists(filename))
{
kdDebug(5950) << "AlarmCalendar::importAlarms(): File '" << url.prettyURL() << "' not found" << endl;
- KMessageBox::error(tqparent, i18n("Could not load calendar '%1'.").tqarg(url.prettyURL()));
+ KMessageBox::error(parent, i18n("Could not load calendar '%1'.").tqarg(url.prettyURL()));
return false;
}
}
@@ -477,7 +477,7 @@ bool AlarmCalendar::importAlarms(TQWidget* tqparent)
if (!KIO::NetAccess::download(url, filename, MainWindow::mainMainWindow()))
{
kdError(5950) << "AlarmCalendar::importAlarms(): Download failure" << endl;
- KMessageBox::error(tqparent, i18n("Cannot download calendar:\n%1").tqarg(url.prettyURL()));
+ KMessageBox::error(parent, i18n("Cannot download calendar:\n%1").tqarg(url.prettyURL()));
return false;
}
kdDebug(5950) << "--- Downloaded to " << filename << endl;
@@ -490,7 +490,7 @@ bool AlarmCalendar::importAlarms(TQWidget* tqparent)
if (!success)
{
kdDebug(5950) << "AlarmCalendar::importAlarms(): error loading calendar '" << filename << "'" << endl;
- KMessageBox::error(tqparent, i18n("Could not load calendar '%1'.").tqarg(url.prettyURL()));
+ KMessageBox::error(parent, i18n("Could not load calendar '%1'.").tqarg(url.prettyURL()));
}
else
{
@@ -439,14 +439,14 @@ void AlarmCalendar::close()
* Import alarms from an external calendar and merge them into KAlarm's calendar.
* The alarms are given new unique event IDs.
-* Parameters: tqparent = tqparent widget for error message boxes
+* Parameters: parent = parent widget for error message boxes
* Reply = true if all alarms in the calendar were successfully imported
* = false if any alarms failed to be imported.